@@ -143,16 +143,17 @@ static void qt_msg_handler(QtMsgType type, const char *msg)
     switch (type)
     {
     case QtDebugMsg:
-        msg::dbg("%s", msg);
+        msg::dbg(str::sanitize(msg));
         break;
     case QtWarningMsg:
-        msg::wrn("%s", msg);
+        msg::wrn(str::sanitize(msg));
         break;
     case QtCriticalMsg:
-        msg::err("%s", msg);
+        msg::err(str::sanitize(msg));
         break;
     case QtFatalMsg:
-        msg::err("%s", msg);
+    default:
+        msg::err(str::sanitize(msg));
         std::exit(1);
     }
 }
@@ -300,7 +301,7 @@ int main(int argc, char *argv[])
     options.push_back(&fullscreen_flip_right);
     opt::flag fullscreen_flop_right("fullscreen-flop-right", '\0', opt::optional);
     options.push_back(&fullscreen_flop_right);
-    opt::flag fullscreen_3d_ready_sync("fullscreen-3d-ready-sync", '\0', opt::optional);
+    opt::flag fullscreen_3d_ready_sync("fullscreen-3dr-sync", '\0', opt::optional);
     options.push_back(&fullscreen_3d_ready_sync);
     opt::val<float> zoom("zoom", 'z', opt::optional, 0.0f, 1.0f);
     options.push_back(&zoom);
